@@ -1,7 +1,7 @@
 /*
- * core-hdata.c - direct access to WeeChat data using hashtables
+ * SPDX-FileCopyrightText: 2011-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2011-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Direct access to WeeChat data using hashtables */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -1244,10 +1246,10 @@ hdata_set (struct t_hdata *hdata, void *pointer, const char *name,
            const char *value)
 {
     struct t_hdata_var *var;
-    void *ptr;
     char **ptr_string, *error;
     long number;
     long long number_longlong;
+    unsigned long ptr;
     int rc;
 
     if (!hdata->update_pending)
@@ -1307,10 +1309,10 @@ hdata_set (struct t_hdata *hdata, void *pointer, const char *name,
         case WEECHAT_HDATA_POINTER:
             if (value)
             {
-                rc = sscanf (value, "%p", &ptr);
+                rc = sscanf (value, "%lx", &ptr);
                 if ((rc != EOF) && (rc != 0))
                 {
-                    *((void **)(pointer + var->offset)) = ptr;
+                    *((void **)(pointer + var->offset)) = (void *)ptr;
                     return 1;
                 }
             }
