@@ -1,7 +1,7 @@
 /*
- * core-signal.c - signal functions
+ * SPDX-FileCopyrightText: 2021-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2021-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Signal functions */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -281,7 +283,7 @@ signal_handle_number (int signal_number, int count, const char *command)
  */
 
 void
-signal_handle ()
+signal_handle (void)
 {
     /* SIGUSR1 */
     signal_handle_number (SIGUSR1, signal_sigusr1_count,
@@ -314,7 +316,7 @@ signal_handle ()
  */
 
 void
-signal_suspend ()
+signal_suspend (void)
 {
     kill (getpid (), SIGTSTP);
     gui_window_ask_refresh (2);
@@ -325,7 +327,7 @@ signal_suspend ()
  */
 
 void
-signal_init ()
+signal_init (void)
 {
     /* ignore some signals */
     signal_catch (SIGINT, SIG_IGN);
