@@ -1,7 +1,7 @@
 /*
- * hook-command-run.c - WeeChat command_run hook
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* WeeChat command_run hook */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -28,6 +30,7 @@
 
 #include "../weechat.h"
 #include "../core-hook.h"
+#include "../core-hdata.h"
 #include "../core-infolist.h"
 #include "../core-log.h"
 #include "../core-string.h"
@@ -113,7 +116,7 @@ hook_command_run_exec (struct t_gui_buffer *buffer, const char *command)
     if (command[0] != '/')
     {
         ptr_string = utf8_next_char (command);
-        if (string_asprintf (&command2, "/%s", ptr_string) < 0)
+        if (string_asprintf (&command2, "/%s", (ptr_string) ? ptr_string : "") < 0)
             return WEECHAT_RC_ERROR;
     }
     else
@@ -201,6 +204,30 @@ hook_command_run_free_data (struct t_hook *hook)
     hook->hook_data = NULL;
 }
 
+/*
+ * Returns hdata for command_run hook.
+ */
+
+struct t_hdata *
+hook_command_run_hdata_hook_command_run_cb (const void *pointer, void *data,
+                                            const char *hdata_name)
+{
+    struct t_hdata *hdata;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+
+    hdata = hdata_new (NULL, hdata_name, NULL, NULL, 0, 0, NULL, NULL);
+    if (hdata)
+    {
+        HDATA_VAR(struct t_hook_command_run, callback, POINTER, 0, NULL, NULL);
+        HDATA_VAR(struct t_hook_command_run, command, STRING, 0, NULL, NULL);
+        HDATA_VAR(struct t_hook_command_run, keep_spaces_right, INTEGER, 0, NULL, NULL);
+    }
+    return hdata;
+}
+
 /*
  * Adds command_run hook data in the infolist item.
  *
