@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -49,6 +51,9 @@ extern struct t_hook *hook_command_run (struct t_weechat_plugin *plugin,
 extern int hook_command_run_exec (struct t_gui_buffer *buffer,
                                   const char *command);
 extern void hook_command_run_free_data (struct t_hook *hook);
+extern struct t_hdata *hook_command_run_hdata_hook_command_run_cb (const void *pointer,
+                                                                   void *data,
+                                                                   const char *hdata_name);
 extern int hook_command_run_add_to_infolist (struct t_infolist_item *item,
                                              struct t_hook *hook);
 extern void hook_command_run_print_log (struct t_hook *hook);
