@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -52,6 +54,9 @@ extern struct t_hook *hook_fd (struct t_weechat_plugin *plugin, int fd,
                                void *callback_data);
 extern void hook_fd_exec (void);
 extern void hook_fd_free_data (struct t_hook *hook);
+extern struct t_hdata *hook_fd_hdata_hook_fd_cb (const void *pointer,
+                                                 void *data,
+                                                 const char *hdata_name);
 extern int hook_fd_add_to_infolist (struct t_infolist_item *item,
                                     struct t_hook *hook);
 extern void hook_fd_print_log (struct t_hook *hook);
