@@ -30,9 +30,11 @@
 
 #include "../weechat.h"
 #include "../core-hook.h"
+#include "../core-hdata.h"
 #include "../core-infolist.h"
 #include "../core-log.h"
 #include "../core-string.h"
+#include "../../plugins/plugin.h"
 
 
 /*
@@ -185,6 +187,32 @@ hook_infolist_free_data (struct t_hook *hook)
     hook->hook_data = NULL;
 }
 
+/*
+ * Returns hdata for infolist hook.
+ */
+
+struct t_hdata *
+hook_infolist_hdata_hook_infolist_cb (const void *pointer, void *data,
+                                      const char *hdata_name)
+{
+    struct t_hdata *hdata;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+
+    hdata = hdata_new (NULL, hdata_name, NULL, NULL, 0, 0, NULL, NULL);
+    if (hdata)
+    {
+        HDATA_VAR(struct t_hook_infolist, callback, POINTER, 0, NULL, NULL);
+        HDATA_VAR(struct t_hook_infolist, infolist_name, STRING, 0, NULL, NULL);
+        HDATA_VAR(struct t_hook_infolist, description, STRING, 0, NULL, NULL);
+        HDATA_VAR(struct t_hook_infolist, pointer_description, STRING, 0, NULL, NULL);
+        HDATA_VAR(struct t_hook_infolist, args_description, STRING, 0, NULL, NULL);
+    }
+    return hdata;
+}
+
 /*
  * Adds infolist hook data in the infolist item.
  *
