@@ -1,7 +1,7 @@
 /*
- * gui-completion.c - word completion according to context (used by all GUI)
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Word completion according to context (used by all GUI) */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -125,8 +127,8 @@ gui_completion_init (struct t_gui_completion *completion,
     completion->args = NULL;
     completion->direction = 0;
     completion->add_space = 1;
-    completion->force_partial_completion = 0;
-    completion->reverse_partial_completion = 0;
+    completion->partial_completion = 0;
+    completion->template_partial_completion = 0;
 
     completion->list = arraylist_new (
         32, 1, 0,
@@ -321,9 +323,11 @@ gui_completion_nick_has_ignored_chars (const char *string)
     int char_size;
     char utf_char[16];
 
-    while (string[0])
+    while (string && string[0])
     {
         char_size = utf8_char_size (string);
+        if (char_size < 1)
+            break;
         memcpy (utf_char, string, char_size);
         utf_char[char_size] = '\0';
 
@@ -350,9 +354,11 @@ gui_completion_nick_strdup_ignore_chars (const char *string)
 
     result = malloc (strlen (string) + 1);
     pos = result;
-    while (string[0])
+    while (string && string[0])
     {
         char_size = utf8_char_size (string);
+        if (char_size < 1)
+            break;
         memcpy (utf_char, string, char_size);
         utf_char[char_size] = '\0';
 
@@ -625,7 +631,7 @@ gui_completion_build_list_template (struct t_gui_completion *completion,
                                                 config_hashtable_completion_partial_templates,
                                                 custom_completion))
                                         {
-                                            completion->reverse_partial_completion = 1;
+                                            completion->template_partial_completion = 1;
                                         }
                                         gui_completion_custom (completion,
                                                                custom_completion,
@@ -901,8 +907,6 @@ gui_completion_find_context (struct t_gui_completion *completion,
     const char *ptr_command, *ptr_data, *ptr_space, *ptr_newline, *prev_char;
 
     /* look for context */
-    gui_completion_free_data (completion);
-    gui_completion_init (completion, completion->plugin, completion->buffer);
     ptr_command = NULL;
     command_arg = 0;
 
@@ -913,13 +917,16 @@ gui_completion_find_context (struct t_gui_completion *completion,
     if (string_is_command_char (ptr_data))
     {
         ptr_data = utf8_next_char (ptr_data);
-        if (ptr_data < data + pos)
+        if (ptr_data)
         {
-            if (string_is_command_char (ptr_data))
-                ptr_data = utf8_next_char (ptr_data);
+            if (ptr_data < data + pos)
+            {
+                if (string_is_command_char (ptr_data))
+                    ptr_data = utf8_next_char (ptr_data);
+            }
+            if (!string_is_command_char (ptr_data))
+                ptr_command = ptr_data;
         }
-        if (!string_is_command_char (ptr_data))
-            ptr_command = ptr_data;
     }
 
     /*
@@ -1232,7 +1239,7 @@ gui_completion_partial_build_list (struct t_gui_completion *completion,
 void
 gui_completion_complete (struct t_gui_completion *completion)
 {
-    int length, word_found_seen, other_completion, partial_completion;
+    int length, word_found_seen, other_completion;
     int common_prefix_size, index, index2;
     struct t_gui_completion_word *ptr_completion_word, *ptr_completion_word2;
 
@@ -1240,34 +1247,15 @@ gui_completion_complete (struct t_gui_completion *completion)
     word_found_seen = 0;
     other_completion = 0;
 
-    partial_completion = completion->force_partial_completion;
-
-    if (!partial_completion)
-    {
-        if (completion->context == GUI_COMPLETION_COMMAND)
-        {
-            partial_completion = CONFIG_BOOLEAN(config_completion_partial_completion_command);
-        }
-        else if (completion->context == GUI_COMPLETION_COMMAND_ARG)
-        {
-            partial_completion = CONFIG_BOOLEAN(config_completion_partial_completion_command_arg);
-        }
-        else
-            partial_completion = CONFIG_BOOLEAN(config_completion_partial_completion_other);
-    }
-
-    if (completion->reverse_partial_completion)
-        partial_completion ^= 1;
-
     common_prefix_size = 0;
-    if (partial_completion
+    if (completion->partial_completion
         && completion->list && (completion->list->size > 0))
     {
         common_prefix_size = gui_completion_common_prefix_size (completion->list,
                                                                 NULL);
     }
 
-    if (partial_completion
+    if (completion->partial_completion
         && completion->word_found
         && (utf8_strlen (completion->word_found) >= common_prefix_size))
     {
@@ -1346,7 +1334,7 @@ gui_completion_complete (struct t_gui_completion *completion)
                         completion->position = 0;
 
                 /* stop after common prefix, if asked by user */
-                if (partial_completion
+                if (completion->partial_completion
                     && ((utf8_strlen (completion->word_found) >= common_prefix_size))
                     && (other_completion > 0))
                 {
@@ -1396,7 +1384,8 @@ gui_completion_complete (struct t_gui_completion *completion)
      * if we was on last completion in list, then complete again, starting from
      * first matching item
      */
-    if (completion->word_found && (completion->position >= 0))
+    if (CONFIG_BOOLEAN(config_completion_cycle)
+        && completion->word_found && (completion->position >= 0))
     {
         free (completion->word_found);
         completion->word_found = NULL;
@@ -1514,7 +1503,7 @@ gui_completion_search (struct t_gui_completion *completion, const char *data,
                        int position, int direction)
 {
     char *old_word_found;
-    int real_position;
+    int real_position, force_no_partial;
 
     if (!completion || !data || (position < 0))
         return 0;
@@ -1523,14 +1512,75 @@ gui_completion_search (struct t_gui_completion *completion, const char *data,
 
     completion->direction = direction;
 
+    force_no_partial = 0;
+    if ((completion->context != GUI_COMPLETION_NULL)
+        && (arraylist_size (completion->partial_list) > 0)
+        && CONFIG_BOOLEAN(config_completion_partial_completion_auto_expand))
+    {
+        force_no_partial = 1;
+        arraylist_clear (completion->partial_list);
+    }
+
     /* if new completion => look for base word */
     if (real_position != completion->position)
     {
         free (completion->word_found);
         completion->word_found = NULL;
         completion->word_found_is_nick = 0;
+        gui_completion_free_data (completion);
+        gui_completion_init (completion, completion->plugin, completion->buffer);
+        completion->partial_completion = (direction < 0);
+        completion->direction = direction;
         gui_completion_find_context (completion, data, real_position);
-        completion->force_partial_completion = (direction < 0);
+        if (force_no_partial)
+        {
+            completion->partial_completion = 0;
+            completion->direction = 1;
+        }
+        else if (completion->template_partial_completion)
+        {
+            if (completion->direction < 0)
+            {
+                completion->partial_completion = 0;
+                completion->direction = 1;
+            }
+            else
+            {
+                completion->partial_completion = 1;
+            }
+        }
+        else
+        {
+            switch (completion->context)
+            {
+                case GUI_COMPLETION_NULL:
+                    break;
+                case GUI_COMPLETION_COMMAND:
+                    if (CONFIG_BOOLEAN(config_completion_partial_completion_command))
+                    {
+                        completion->partial_completion ^= 1;
+                        if (completion->direction < 0)
+                            completion->direction = 1;
+                    }
+                    break;
+                case GUI_COMPLETION_COMMAND_ARG:
+                    if (CONFIG_BOOLEAN(config_completion_partial_completion_command_arg))
+                    {
+                        completion->partial_completion ^= 1;
+                        if (completion->direction < 0)
+                            completion->direction = 1;
+                    }
+                    break;
+                case GUI_COMPLETION_AUTO:
+                    if (CONFIG_BOOLEAN(config_completion_partial_completion_other))
+                    {
+                        completion->partial_completion ^= 1;
+                        if (completion->direction < 0)
+                            completion->direction = 1;
+                    }
+                    break;
+            }
+        }
     }
 
     /* completion */
@@ -1647,8 +1697,8 @@ gui_completion_hdata_completion_cb (const void *pointer, void *data,
         HDATA_VAR(struct t_gui_completion, args, STRING, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_completion, direction, INTEGER, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_completion, add_space, INTEGER, 0, NULL, NULL);
-        HDATA_VAR(struct t_gui_completion, force_partial_completion, INTEGER, 0, NULL, NULL);
-        HDATA_VAR(struct t_gui_completion, reverse_partial_completion, INTEGER, 0, NULL, NULL);
+        HDATA_VAR(struct t_gui_completion, partial_completion, INTEGER, 0, NULL, NULL);
+        HDATA_VAR(struct t_gui_completion, template_partial_completion, INTEGER, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_completion, list, POINTER, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_completion, word_found, STRING, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_completion, word_found_is_nick, INTEGER, 0, NULL, NULL);
@@ -1722,30 +1772,30 @@ gui_completion_print_log (void)
          ptr_completion = ptr_completion->next_completion)
     {
         log_printf ("[completion (addr:%p)]", ptr_completion);
-        log_printf ("  plugin. . . . . . . . . . : %p", ptr_completion->plugin);
-        log_printf ("  buffer. . . . . . . . . . : %p ('%s')",
+        log_printf ("  plugin. . . . . . . . . . . : %p", ptr_completion->plugin);
+        log_printf ("  buffer. . . . . . . . . . . : %p ('%s')",
                     ptr_completion->buffer,
                     ptr_completion->buffer->full_name);
-        log_printf ("  context . . . . . . . . . : %d", ptr_completion->context);
-        log_printf ("  case_sensitive. . . . . . : %d", ptr_completion->case_sensitive);
-        log_printf ("  base_command. . . . . . . : '%s'", ptr_completion->base_command);
-        log_printf ("  base_command_arg_index. . : %d", ptr_completion->base_command_arg_index);
-        log_printf ("  base_word . . . . . . . . : '%s'", ptr_completion->base_word);
-        log_printf ("  base_word_pos . . . . . . : %d", ptr_completion->base_word_pos);
-        log_printf ("  position. . . . . . . . . : %d", ptr_completion->position);
-        log_printf ("  args. . . . . . . . . . . : '%s'", ptr_completion->args);
-        log_printf ("  direction . . . . . . . . : %d", ptr_completion->direction);
-        log_printf ("  add_space . . . . . . . . : %d", ptr_completion->add_space);
-        log_printf ("  force_partial_completion. : %d", ptr_completion->force_partial_completion);
-        log_printf ("  reverse_partial_completion: %d", ptr_completion->reverse_partial_completion);
-        log_printf ("  list. . . . . . . . . . . : %p", ptr_completion->list);
-        log_printf ("  word_found. . . . . . . . : '%s'", ptr_completion->word_found);
-        log_printf ("  word_found_is_nick. . . . : %d", ptr_completion->word_found_is_nick);
-        log_printf ("  position_replace. . . . . : %d", ptr_completion->position_replace);
-        log_printf ("  diff_size . . . . . . . . : %d", ptr_completion->diff_size);
-        log_printf ("  diff_length . . . . . . . : %d", ptr_completion->diff_length);
-        log_printf ("  prev_completion . . . . . : %p", ptr_completion->prev_completion);
-        log_printf ("  next_completion . . . . . : %p", ptr_completion->next_completion);
+        log_printf ("  context . . . . . . . . . . : %d", ptr_completion->context);
+        log_printf ("  case_sensitive. . . . . . . : %d", ptr_completion->case_sensitive);
+        log_printf ("  base_command. . . . . . . . : '%s'", ptr_completion->base_command);
+        log_printf ("  base_command_arg_index. . . : %d", ptr_completion->base_command_arg_index);
+        log_printf ("  base_word . . . . . . . . . : '%s'", ptr_completion->base_word);
+        log_printf ("  base_word_pos . . . . . . . : %d", ptr_completion->base_word_pos);
+        log_printf ("  position. . . . . . . . . . : %d", ptr_completion->position);
+        log_printf ("  args. . . . . . . . . . . . : '%s'", ptr_completion->args);
+        log_printf ("  direction . . . . . . . . . : %d", ptr_completion->direction);
+        log_printf ("  add_space . . . . . . . . . : %d", ptr_completion->add_space);
+        log_printf ("  partial_completion. . . . . : %d", ptr_completion->partial_completion);
+        log_printf ("  template_partial_completion : %d", ptr_completion->template_partial_completion);
+        log_printf ("  list. . . . . . . . . . . . : %p", ptr_completion->list);
+        log_printf ("  word_found. . . . . . . . . : '%s'", ptr_completion->word_found);
+        log_printf ("  word_found_is_nick. . . . . : %d", ptr_completion->word_found_is_nick);
+        log_printf ("  position_replace. . . . . . : %d", ptr_completion->position_replace);
+        log_printf ("  diff_size . . . . . . . . . : %d", ptr_completion->diff_size);
+        log_printf ("  diff_length . . . . . . . . : %d", ptr_completion->diff_length);
+        log_printf ("  prev_completion . . . . . . : %p", ptr_completion->prev_completion);
+        log_printf ("  next_completion . . . . . . : %p", ptr_completion->next_completion);
         if (ptr_completion->list && (ptr_completion->list->size > 0))
         {
             log_printf ("");
