@@ -1,7 +1,7 @@
 /*
- * gui-key.c - keyboard functions (used by all GUI)
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Keyboard functions (used by all GUI) */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -1326,7 +1328,7 @@ gui_key_chunk_seems_valid (const char *chunk)
     if (!found)
         chunk = utf8_next_char (chunk);
 
-    if (chunk[0])
+    if (chunk && chunk[0])
         return 0;
 
     return 1;
@@ -2042,6 +2044,7 @@ gui_key_focus_command (const char *key, int context,
 {
     struct t_gui_key *ptr_key;
     int matching, debug, rc;
+    unsigned long value;
     char *command, **commands, **ptr_command;
     const char *str_buffer;
     struct t_hashtable *hashtable;
@@ -2099,9 +2102,9 @@ gui_key_focus_command (const char *key, int context,
         str_buffer = hashtable_get (hashtable, "_buffer");
         if (str_buffer && str_buffer[0])
         {
-            rc = sscanf (str_buffer, "%p", &ptr_buffer);
-            if ((rc == EOF) || (rc == 0))
-                ptr_buffer = gui_current_window->buffer;
+            rc = sscanf (str_buffer, "%lx", &value);
+            if ((rc != EOF) && (rc != 0))
+                ptr_buffer = (struct t_gui_buffer *)value;
         }
         if (!ptr_buffer)
             continue;
