@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -74,7 +76,7 @@ struct t_gui_lines
 
 /* line functions */
 
-extern struct t_gui_lines *gui_line_lines_alloc ();
+extern struct t_gui_lines *gui_line_lines_alloc (void);
 extern void gui_line_lines_free (struct t_gui_lines *lines);
 extern void gui_line_tags_alloc (struct t_gui_line_data *line_data,
                                  const char *tags);
