@@ -1,7 +1,7 @@
 /*
- * gui-window.c - window functions (used by all GUI)
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Window functions (used by all GUI) */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -183,6 +185,8 @@ gui_window_get_context_at_xy (struct t_gui_window *window,
     *chat = 1;
 
     /* get line */
+    if (win_y >= window->coords_size)
+        return;
     *line = window->coords[win_y].line;
     if (!*line)
         return;
@@ -220,6 +224,7 @@ gui_window_get_context_at_xy (struct t_gui_window *window,
     {
         /* X is in message (or after) */
         data_next_line = ((win_y < window->win_chat_height - 1)
+                          && (win_y + 1 < window->coords_size)
                           && (window->coords[win_y + 1].line == *line)) ?
             window->coords[win_y + 1].data : NULL;
         ptr_data = gui_chat_string_add_offset_screen (window->coords[win_y].data,
