@@ -1,7 +1,7 @@
 /*
- * fifo.c - fifo plugin for WeeChat: remote control with FIFO pipe
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Fifo plugin for WeeChat: remote control with FIFO pipe */
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -62,7 +64,7 @@ int fifo_fd_cb (const void *pointer, void *data, int fd);
  */
 
 void
-fifo_create ()
+fifo_create (void)
 {
     struct stat st;
     struct t_hashtable *options;
@@ -146,7 +148,7 @@ fifo_create ()
  */
 
 void
-fifo_remove ()
+fifo_remove (void)
 {
     int fifo_found;
 
@@ -284,13 +286,7 @@ fifo_fd_cb (const void *pointer, void *data, int fd)
         ptr_buf = buffer;
         if (fifo_unterminated)
         {
-            buf2 = malloc (strlen (fifo_unterminated) +
-                           strlen (buffer) + 1);
-            if (buf2)
-            {
-                strcpy (buf2, fifo_unterminated);
-                strcat (buf2, buffer);
-            }
+            weechat_asprintf (&buf2, "%s%s", fifo_unterminated, buffer);
             ptr_buf = buf2;
             free (fifo_unterminated);
             fifo_unterminated = NULL;
