@@ -1,7 +1,7 @@
 /*
- * fset-info.c - info, infolist and hdata hooks for Fast Set plugin
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Info, infolist and hdata hooks for Fast Set plugin */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -94,7 +96,7 @@ fset_info_infolist_fset_option_cb (const void *pointer, void *data,
  */
 
 void
-fset_info_init ()
+fset_info_init (void)
 {
     /* infolist hooks */
     weechat_hook_infolist (
