@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,12 +24,12 @@
 
 extern char **script_actions;
 
-extern int script_action_run_all ();
+extern int script_action_run_all (void);
 extern void script_action_schedule (struct t_gui_buffer *buffer,
                                     const char *action,
                                     int need_repository,
                                     int error_repository,
                                     int quiet);
-extern void script_action_end ();
+extern void script_action_end (void);
 
 #endif /* WEECHAT_PLUGIN_SCRIPT_ACTION_H */
