@@ -1,9 +1,9 @@
 /*
- * spell.c - spell checker plugin for WeeChat
+ * SPDX-FileCopyrightText: 2006 Emmanuel Bouthenot <kolter@openics.org>
+ * SPDX-FileCopyrightText: 2006-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2012 Nils Görs <weechatter@arcor.de>
  *
- * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2025 Sébastien Helleu <flashcode@flashtux.org>
- * Copyright (C) 2012 Nils Görs <weechatter@arcor.de>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -21,6 +21,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Spell checker plugin for WeeChat */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -713,6 +715,7 @@ spell_modifier_cb (const void *pointer, void *data,
                    const char *modifier,
                    const char *modifier_data, const char *string)
 {
+    unsigned long value;
     struct t_gui_buffer *buffer;
     struct t_spell_speller_buffer *ptr_speller_buffer;
     char **result, *ptr_string, *ptr_string_orig, *pos_space;
@@ -735,10 +738,12 @@ spell_modifier_cb (const void *pointer, void *data,
     if (!string)
         return NULL;
 
-    rc = sscanf (modifier_data, "%p", &buffer);
+    rc = sscanf (modifier_data, "%lx", &value);
     if ((rc == EOF) || (rc == 0))
         return NULL;
 
+    buffer = (struct t_gui_buffer *)value;
+
     /* check text during search only if option is enabled */
     if (weechat_buffer_get_integer (buffer, "text_search")
         && !weechat_config_boolean (spell_config_check_during_search))
@@ -832,7 +837,7 @@ spell_modifier_cb (const void *pointer, void *data,
     }
 
     current_pos = 0;
-    while (ptr_string[0])
+    while (ptr_string && ptr_string[0])
     {
         ptr_string_orig = NULL;
 
@@ -883,7 +888,7 @@ spell_modifier_cb (const void *pointer, void *data,
                 word_end_pos_valid = word_end_pos;
             }
             ptr_end = (char *)weechat_utf8_next_char (ptr_end);
-            if (!ptr_end[0])
+            if (!ptr_end || !ptr_end[0])
                 break;
             code_point = weechat_utf8_char_int (ptr_end);
         }
@@ -904,7 +909,7 @@ spell_modifier_cb (const void *pointer, void *data,
                 while (!iswspace (code_point))
                 {
                     ptr_end = (char *)weechat_utf8_next_char (ptr_end);
-                    if (!ptr_end[0])
+                    if (!ptr_end || !ptr_end[0])
                         break;
                     code_point = weechat_utf8_char_int (ptr_end);
                 }
@@ -1118,12 +1123,8 @@ spell_debug_libs_cb (const void *pointer, void *data, const char *signal,
     (void) signal_data;
 
 #ifdef USE_ENCHANT
-#ifdef HAVE_ENCHANT_GET_VERSION
     weechat_printf (NULL, "  %s: enchant %s",
                     SPELL_PLUGIN_NAME, enchant_get_version ());
-#else
-    weechat_printf (NULL, "  %s: enchant (?)", SPELL_PLUGIN_NAME);
-#endif /* HAVE_ENCHANT_GET_VERSION */
 #else
 #ifdef HAVE_ASPELL_VERSION_STRING
     weechat_printf (NULL, "  %s: aspell %s",
