@@ -1,7 +1,7 @@
 /*
- * test-hook-fd.cpp - test hook fd functions
+ * SPDX-FileCopyrightText: 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,9 +19,11 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Test hook fd functions */
+
 #include "CppUTest/TestHarness.h"
 
-#include "tests/tests.h"
+#include "tests.h"
 
 extern "C"
 {
